Appsignal (AppSignal v2.17.0)

Copy Markdown View Source

AppSignal for Elixir. Follow the installation guide to install AppSignal into your Elixir app.

This module contains the main AppSignal OTP application, as well as a few helper functions for sending metrics to AppSignal.

Summary

Functions

add_distribution_value(key, value, tags \\ %{})

@spec add_distribution_value(String.t(), float() | integer(), map()) :: :ok

Add a value to a distribution

Use this to collect multiple data points that will be merged into a graph.

heartbeat(name)

This function is deprecated. Use `Appsignal.CheckIn.cron/1` instead..
@spec heartbeat(String.t()) :: :ok

See Appsignal.CheckIn.cron/1.

heartbeat(name, fun)

This function is deprecated. Use `Appsignal.CheckIn.cron/2` instead..
@spec heartbeat(String.t(), (-> out)) :: out when out: var

See Appsignal.CheckIn.cron/2.

increment_counter(key, count \\ 1, tags \\ %{})

@spec increment_counter(String.t(), number(), map()) :: :ok

Increment a counter of a metric.

instrument(fun)

See Appsignal.Instrumentation.instrument/1.

instrument(name, fun)

See Appsignal.Instrumentation.instrument/2.

instrument(name, category, fun)

See Appsignal.Instrumentation.instrument/3.

send_error(exception, stacktrace)

See Appsignal.Instrumentation.send_error/2.

send_error(kind, reason, stacktrace)

See Appsignal.Instrumentation.send_error/3.

send_error(kind, reason, stacktrace, fun)

See Appsignal.Instrumentation.send_error/4.

set_error(exception, stacktrace)

See Appsignal.Instrumentation.set_error/2.

set_error(kind, reason, stacktrace)

See Appsignal.Instrumentation.set_error/3.

set_gauge(key, value, tags \\ %{})

@spec set_gauge(String.t(), float() | integer(), map()) :: :ok

Set a gauge for a measurement of a metric.